@@ -29,8 +29,7 @@ def get_quote_type(code: str):
 
 def remove_quotes(code: str):
     quote_type = get_quote_type(code)
-    body = code[len(quote_type) : -len(quote_type)]
-    return body
+    return code[len(quote_type) : -len(quote_type)]
 
 
 def set_quote_type(code: str, quote_type: str):
