@@ -43,9 +43,13 @@ def formatted_value(fmt_prefix, fmt_spec, val):
         fmt_spec = translate_conversion_types.get(fmt_spec, fmt_spec)
         if fmt_spec == "d":
             if state.aggressive:
-                val = ast.Call(
-                    func=ast.Name(id="int", ctx=ast.Load()), args=[val], keywords={}
-                )
+                if isinstance(val, ast.Call) and val.func.id == "len":
+                    # don't wrap len() into int() - assume it returns int already. see issue #108 on github
+                    pass
+                else:
+                    val = ast.Call(
+                        func=ast.Name(id="int", ctx=ast.Load()), args=[val], keywords={}
+                    )
                 fmt_spec = ""
             else:
                 raise FlyntException(
@@ -70,9 +74,7 @@ def transform_dict(node):
     format_str = node.left.s
     matches = DICT_PATTERN.findall(format_str)
     if len(matches) != len(ANY_DICT.findall(format_str)):
-        raise FlyntException(
-            "Some locations have unknown format modifiers."
-        )
+        raise FlyntException("Some locations have unknown format modifiers.")
 
     spec = []
     for idx, m in enumerate(matches):
@@ -176,7 +178,9 @@ def transform_generic(node):
         return transform_dict(node), True
 
     # if it's just a name then pretend it's tuple to use that code
-    str_in_str = any(isinstance(n, (ast.Str, ast.JoinedStr)) for n in ast.walk(node.right))
+    str_in_str = any(
+        isinstance(n, (ast.Str, ast.JoinedStr)) for n in ast.walk(node.right)
+    )
 
     node.right = ast.Tuple(elts=[node.right])
     return transform_tuple(node), str_in_str
@@ -194,14 +198,14 @@ supported_operands = [
 
 
 def transform_binop(node):
-    if isinstance(
-        node.right,
-        tuple(supported_operands),
-    ):
+    if isinstance(node.right, tuple(supported_operands)):
         return transform_generic(node)
 
     elif isinstance(node.right, ast.Tuple):
-        return transform_tuple(node), False
+        return (
+            transform_tuple(node),
+            any(isinstance(n, (ast.Str, ast.JoinedStr)) for n in ast.walk(node.right)),
+        )
 
     elif isinstance(node.right, ast.Dict):
         # todo adapt transform dict to Dict literal
